@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: snap-server
-version: 0.5.3.1
-id: snap-server-0.5.3.1-e62f799601b0c43812fd7d4a4cf70b34
+version: 0.7.0.1
+id: snap-server-0.7.0.1-1b9dd3cf9e426dc7b599dbcdbb6761bb
 
 license: BSD3
 copyright:
@@ -26,15 +26,15 @@ description: Snap is a simple and fast web development framework and server writ
              as Java servlets, or
              .
              * are interested in contributing to the Snap Framework project.
-category: Web
+category: Web, Snap
 author: James Sanders, Gregory Collins, Doug Beardsley
 pkgpath: www/hs-snap-server
 exposed: True
 exposed-modules: Snap.Http.Server Snap.Http.Server.Config
                  System.FastLogger
 hidden-modules: Paths_snap_server Data.Concurrent.HashMap
-                Data.Concurrent.HashMap.Internal Snap.Internal.Http.Parser
-                Snap.Internal.Http.Server Snap.Internal.Http.Server.Date
+                Snap.Internal.Http.Parser Snap.Internal.Http.Server
+                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Date
                 Snap.Internal.Http.Server.Backend
                 Snap.Internal.Http.Server.ListenHelpers
                 Snap.Internal.Http.Server.HttpPort
@@ -42,9 +42,9 @@ hidden-modules: Paths_snap_server Data.Concurrent.HashMap
                 Snap.Internal.Http.Server.TimeoutManager
                 Snap.Internal.Http.Server.TLS
                 Snap.Internal.Http.Server.LibevBackend
-import-dirs: /usr/local/lib/ghc/snap-server-0.5.3.1
-library-dirs: /usr/local/lib/ghc/snap-server-0.5.3.1
-hs-libraries: HSsnap-server-0.5.3.1
+import-dirs: /usr/local/lib/ghc/snap-server-0.7.0.1
+library-dirs: /usr/local/lib/ghc/snap-server-0.7.0.1
+hs-libraries: HSsnap-server-0.7.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
@@ -52,8 +52,8 @@ includes:
 depends: MonadCatchIO-transformers-0.2.2.0-f749ec9c65171550034463cf701d6100
          PSQueue-1.1-a871ed0984eeaa78f8e94095583b35cc
          array-0.3.0.2-143060371bda4ff52c270d1067551fe8
-         attoparsec-0.8.6.1-6571973e9a458e9ceb9b784270798e62
-         attoparsec-enumerator-0.2.0.3-7161253b2694c3a63f8802608904707a
+         attoparsec-0.10.1.0-1b8be2d38891f85a0546c249120007b2
+         attoparsec-enumerator-0.3-6e24b4e67bc83c2907b44fc43ff25c61
          base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
          binary-0.5.0.2-6eebab9f2e28e2aceb2e2ddd3b4b1ca1
          blaze-builder-0.2.1.4-a9a25d33e6d6a838e2cd173ee4fe6a2b
@@ -69,12 +69,12 @@ depends: MonadCatchIO-transformers-0.2.2.0-f749ec9c65171550034463cf701d6100
          murmur-hash-0.1.0.2-84236d963ec095b8dd8b79cb14107413
          network-2.3.0.5-435de5913c7c66da653cc03396522a6b
          old-locale-1.0.0.2-161f79060c89cc16ca11576ceb440486
-         snap-core-0.5.3.1-dffd36a79bf080ee537b61fe6fb81744
+         snap-core-0.7.0.1-716f035ae7af1b19af1c59d5172cce0e
          template-haskell-2.5.0.0-b8491f77d06d290bb99ada53d74aa786
          text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
          time-1.2.0.3-3493203919ef238f1a58223fa55b1ceb
          transformers-0.2.2.0-4bbbfde1fb5c4eb17cdb1963dda698f3
-         unix-2.4.2.0-c912ec30ca1e7b6067d14990189a1353
+         unix-2.4.2.0-ede8c1b2fd228f3f436412134498aafc
          unix-compat-0.2-9216f37afe4b8111ce6e5fd663b85f80
          vector-0.7.1-8801549ab29457801fbe1eca2f7ad3c5
          vector-algorithms-0.4-f94cfcc745ef6094d5a7d3dbe47ab4f5
@@ -83,6 +83,6 @@ cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-snap-server-0.5.3.1/html/snap-server.haddock
-haddock-html: /usr/local/share/doc/hs-snap-server-0.5.3.1/html
+haddock-interfaces: /usr/local/share/doc/hs-snap-server-0.7.0.1/html/snap-server.haddock
+haddock-html: /usr/local/share/doc/hs-snap-server-0.7.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
